const { app, BrowserWindow, Tray } = require('electron');

const path = require('path');
const isDev = require('electron-is-dev');
const ioHook = require('iohook');
const assetsDirectory = path.join(__dirname, 'assets')
const { setConfig } = require('./utils/configurator')
const { collect } = require('./utils/tracker');

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.
let config = {};
const [ configFromArgument ] = process.argv.slice(-1);

if (configFromArgument !== undefined) {
  try {
    config = JSON.parse(configFromArgument);
  } catch (error) {
    console.log('JSON IS INVALID');
  }
}

if (Object.entries(config).length > 0) {
  setConfig(config);
}

let mainWindow;
let tray;

function createWindow() {
  mainWindow = new BrowserWindow({
    width: 900,
    height: 680,
    show: false,
    frame: false,
    fullscreenable: false,
    resizable: false,
    transparent: true
  });
  mainWindow.loadURL(isDev ? 'http://localhost:3000' : `file://${path.join(__dirname, '../build/index.html')}`);
  if (isDev) {
    // Open the DevTools.
    //BrowserWindow.addDevToolsExtension('<location to your react chrome extension>');
    mainWindow.webContents.openDevTools();
  }
  mainWindow.on('closed', () => mainWindow = null);
}

const createTray = () => {
  tray = new Tray(path.join(assetsDirectory, 'cloudTemplate.png'))
}

app.on('ready', () => {
  createTray()
  createWindow()
})


app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') {
    app.quit();
  }
});

app.on('activate', () => {
  if (mainWindow === null) {
    createWindow();
  }
});

const exit = () => {
  console.log('TEAR DOWN!');
  process.kill();
  process.exit(0);
}

app.on('before-quit', exit);
process.on('SIGTERM', exit);
process.on('SIGINT', exit);

ioHook.on("keypress", function (msg) { collect(msg); });
ioHook.on("mousemove", function (msg) { collect(msg); });

ioHook.start();